@@ -31,9 +31,7 @@ PluginInformer::~PluginInformer()
 
 void PluginInformer::removePluginUser(IPluginUser* pUser)
 {
-	PluginUserContainer::iterator it = find(_users.begin(), _users.end(), pUser);
-	if (it != _users.end())
-		_users.erase(it);
+	_users.erase(pUser);
 }
 
 void PluginInformer::informAddPlugin(Plugin* pPlugin)
