@@ -88,16 +88,6 @@ void AptSearchPlugin::init(IProvider* pProvider)
 		SIGNAL(toggled(bool)), 
 		SLOT(evaluateSearch())
 	);
-	connect(
-		_pShortInputWidget->_pCaseSensitiveCheck,
-		SIGNAL(toggled(bool)), 
-		SLOT(evaluateSearch())
-	);
-	connect(
-		_pShortInputWidget->_pWholeWordsCheck,
-		SIGNAL(toggled(bool)), 
-		SLOT(evaluateSearch())
-	);
 }
 
 /////////////////////////////////////////////////////
@@ -131,7 +121,6 @@ map<string, float> AptSearchPlugin::getScore(const set<string>& packages) const
 {
 	assert(!_includePatterns.empty());
 	_pScoreCalculationStrategy->clear();
-	_pScoreCalculationStrategy->setCaseSensitive(_pShortInputWidget->_pCaseSensitiveCheck->isChecked());
 	_pScoreCalculationStrategy->setIncludePatterns(_includePatterns);
 	_pScoreCalculationStrategy->calculateScore(packages);
 	return _pScoreCalculationStrategy->getScore();
@@ -166,9 +155,7 @@ void AptSearchPlugin::evaluateSearch()
 				_searchResult, 
 				_includePatterns, 
 				_excludePatterns,  
-				_pShortInputWidget->_pSearchDescriptionsCheck->isChecked(),
-				_pShortInputWidget->_pCaseSensitiveCheck->isChecked(),
-				_pShortInputWidget->_pWholeWordsCheck->isChecked()
+				_pShortInputWidget->_pSearchDescriptionsCheck->isChecked()
 			);
 		} catch (...) {
 			qWarning("Search threw an exception -> reloading apt-database");
@@ -178,9 +165,7 @@ void AptSearchPlugin::evaluateSearch()
 					_searchResult, 
 					_includePatterns, 
 					_excludePatterns,  
-					_pShortInputWidget->_pSearchDescriptionsCheck->isChecked(),
-					_pShortInputWidget->_pCaseSensitiveCheck->isChecked(),
-					_pShortInputWidget->_pWholeWordsCheck->isChecked()
+					_pShortInputWidget->_pSearchDescriptionsCheck->isChecked()
 				);
 			} catch (...) {
 				qCritical("apt-search threw an exception -> expect corrupted results");
@@ -205,8 +190,6 @@ void AptSearchPlugin::parseSearchExpression(const QString& expression)
 	QStringList patterns = expression.split('"', QString::KeepEmptyParts);
 	
 	// status flags
-	// invariant:   !(minus && plus)
-	bool plus = false;
 	bool minus = false;
 	bool inGroup = (expression == QString("\""));
 	for (QStringList::iterator it = patterns.begin(); it != patterns.end(); ++it )
@@ -221,14 +204,12 @@ void AptSearchPlugin::parseSearchExpression(const QString& expression)
 					continue;
 				if (p[0] == '+')
 				{
-					plus = true;
 					minus = false;
 					p = p.mid(1);
 				}
 				else if (p[0] == '-')
 				{
 					minus = true;
-					plus = false;
 					p = p.mid(1);
 				}
 				if (p.isEmpty())
@@ -236,7 +217,6 @@ void AptSearchPlugin::parseSearchExpression(const QString& expression)
 				if (!minus)
 				{
 					_includePatterns.push_back(p);
-					plus = false;
 				}
 				else
 				{
@@ -252,7 +232,6 @@ void AptSearchPlugin::parseSearchExpression(const QString& expression)
 			if (!minus)
 			{
 				_includePatterns.push_back(*it);
-				plus = false;
 			}
 			else
 			{
