@@ -300,6 +300,7 @@ bool VocabularyModel::setData(const QModelIndex& index, const QVariant& value, i
 
 void VocabularyModel::setAllUnselected()
 {
+	beginResetModel();
 	QModelIndex parent = QModelIndex();
 	for(int i = 0; i < rowCount(parent); ++i)
 	{
@@ -307,8 +308,7 @@ void VocabularyModel::setAllUnselected()
 		setAllUnselected(newParent);
 	}
 	//_companionTagsValid = false;
-	reset();
-}
+	endResetModel();}
 
 void VocabularyModel::setAllUnselected(QModelIndex index)
 {
