@@ -105,7 +105,7 @@ public:
 	virtual void viewFile(QString filename);
 	/** @brief Enables or disables the "Show" button. */
 	void setShowButtonEnabled(bool enabled);
-protected slots:
+protected Q_SLOTS:
 	/** @brief Called whenever one of the processes (executing <tt>see</tt>) exited.
 	  *
 	  * It tries to detect if the process exited successfully and if not it 
