@@ -72,6 +72,17 @@ public:
 	  */
 	virtual void setTitle(const QString& title)=0;
 
+   // Docu Taken from QT
+	/** Blocks until the process has finished and the finished() signal has been emitted, 
+	  * or until msecs milliseconds have passed.
+	  * Returns true if the process finished; otherwise returns false (if the operation 
+	  * timed out or if an error occurred). 
+     */
+	virtual bool waitForFinished(int msecs = 30000 ) = 0;
+	
+	/** @brief Returns true if the process has already finished, else false. */
+	virtual bool finished() = 0;
+
 	/** @brief Sets the command to be used to become root.
 	  *
 	  * Default is <tt>su</tt>.
